=======
Credits
=======

Development Lead
----------------

Karl Segl <segl@gfz-potsdam.de>

Contributors
------------

* Daniel Scheffler <danschef@gfz-potsdam.de>
  (main developer of the source code)
